@@ -138,7 +138,7 @@ void CalendarJanitor::onModifyFinished(int changeId, const Akonadi::Item &item,
 }
 
 void CalendarJanitor::onDeleteFinished(int changeId,
-                                       const QVector<Akonadi::Item::Id> &items,
+                                       const QList<Akonadi::Item::Id> &items,
                                        Akonadi::IncidenceChanger::ResultCode resultCode,
                                        const QString &errorMessage)
 {
@@ -659,3 +659,5 @@ void CalendarJanitor::deleteIncidence(const Akonadi::Item &item)
         m_incidenceToItem.remove(incidence);
     }
 }
+
+#include "moc_calendarjanitor.cpp"
